==> 0.2.6.tar.gz: android/src/main/kotlin/com/bundle/bundle_rave_pay/BundleData.java <==
package com.bundle.bundle_rave_pay;


import android.os.Parcel;
import android.os.Parcelable;


public class BundleData implements Parcelable {
    private double amount;
    private String cvv;
    private String cardExpiry;
    private String cardNumber;
    private String publicKey;
    private String encryptionKey;
    private String secretKey;
    private String countryCode;
    private String currencyCode;
    private String email;
    private String firstName;
    private String lastName;
    private String narration;
    private String transactionReference;
    private boolean isLive;
    private boolean saveCard;
    private boolean isCard;
    private boolean isAccount;
    private boolean isBankTransfer;


    public BundleData(double amount, String cvv, String cardExpiry, String cardNumber, String publicKey, String encryptionKey, String secretKey, String countryCode,
                      String currencyCode, String email, String firstName, String lastName, String narration, String transactionReference, boolean isLive,
                      boolean saveCard, boolean isCard, boolean isAccount, boolean isBankTransfer) {
        this.amount = amount;
        this.cvv = cvv;
        this.cardExpiry = cardExpiry;
        this.cardNumber = cardNumber;
        this.publicKey = publicKey;
        this.encryptionKey = encryptionKey;
        this.secretKey = secretKey;
        this.countryCode = countryCode;
        this.currencyCode = currencyCode;
        this.email = email;
        this.firstName = firstName;
        this.lastName = lastName;
        this.narration = narration;
        this.transactionReference = transactionReference;
        this.isLive = isLive;
        this.saveCard = saveCard;
        this.isCard = isCard;
        this.isAccount = isAccount;
        this.isBankTransfer = isBankTransfer;
    }

    protected BundleData(Parcel in) {
        amount = in.readDouble();
        cvv = in.readString();
        cardExpiry = in.readString();
        cardNumber = in.readString();
        publicKey = in.readString();
        encryptionKey = in.readString();
        secretKey = in.readString();
        countryCode = in.readString();
        currencyCode = in.readString();
        email = in.readString();
        firstName = in.readString();
        lastName = in.readString();
        narration = in.readString();
        transactionReference = in.readString();
        isLive = in.readByte() != 0;
        saveCard = in.readByte() != 0;
        isCard = in.readByte() != 0;
        isAccount = in.readByte() != 0;
        isBankTransfer = in.readByte() != 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeDouble(amount);
        dest.writeString(cvv);
        dest.writeString(cardExpiry);
        dest.writeString(cardNumber);
        dest.writeString(publicKey);
        dest.writeString(encryptionKey);
        dest.writeString(secretKey);
        dest.writeString(countryCode);
        dest.writeString(currencyCode);
        dest.writeString(email);
        dest.writeString(firstName);
        dest.writeString(lastName);
        dest.writeString(narration);
        dest.writeString(transactionReference);
        dest.writeByte((byte) (isLive ? 1 : 0));
        dest.writeByte((byte) (saveCard ? 1 : 0));
        dest.writeByte((byte) (isCard ? 1 : 0));
        dest.writeByte((byte) (isAccount ? 1 : 0));
        dest.writeByte((byte) (isBankTransfer ? 1 : 0));
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<BundleData> CREATOR = new Creator<BundleData>() {
        @Override
        public BundleData createFromParcel(Parcel in) {
            return new BundleData(in);
        }

        @Override
        public BundleData[] newArray(int size) {
            return new BundleData[size];
        }
    };

    public double getAmount() {
        return amount;
    }

    public void setAmount(double amount) {
        this.amount = amount;
    }

    public String getCvv() {
        return cvv;
    }

    public void setCvv(String cvv) {
        this.cvv = cvv;
    }

    public String getCardExpiry() {
        return cardExpiry;
    }

    public void setCardExpiry(String cardExpiry) {
        this.cardExpiry = cardExpiry;
    }

    public String getCardNumber() {
        return cardNumber;
    }

    public void setCardNumber(String cardNumber) {
        this.cardNumber = cardNumber;
    }

    public String getPublicKey() {
        return publicKey;
    }

    public void setPublicKey(String publicKey) {
        this.publicKey = publicKey;
    }

    public String getEncryptionKey() {
        return encryptionKey;
    }

    public void setEncryptionKey(String encryptionKey) {
        this.encryptionKey = encryptionKey;
    }

    public String getSecretKey() {
        return secretKey;
    }

    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getCurrencyCode() {
        return currencyCode;
    }

    public void setCurrencyCode(String currencyCode) {
        this.currencyCode = currencyCode;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    public String getNarration() {
        return narration;
    }

    public void setNarration(String narration) {
        this.narration = narration;
    }

    public String getTransactionReference() {
        return transactionReference;
    }

    public void setTransactionReference(String transactionReference) {
        this.transactionReference = transactionReference;
    }

    public boolean isLive() {
        return isLive;
    }

    public void setLive(boolean live) {
        isLive = live;
    }

    public boolean isSaveCard() {
        return saveCard;
    }

    public void setSaveCard(boolean saveCard) {
        this.saveCard = saveCard;
    }

    public boolean isCard() {
        return isCard;
    }

    public void setCard(boolean card) {
        isCard = card;
    }

    public boolean isAccount() {
        return isAccount;
    }

    public void setAccount(boolean account) {
        isAccount = account;
    }

    public boolean isBankTransfer() {
        return isBankTransfer;
    }

    public void setBankTransfer(boolean bankTransfer) {
        isBankTransfer = bankTransfer;
    }
}

==> 0.5.7.tar.gz: android/src/main/kotlin/com/bundle/bundle_rave_pay/BundleData.java <==
package com.bundle.bundle_rave_pay;


import android.os.Parcel;
import android.os.Parcelable;


public class BundleData implements Parcelable {
    private double amount;
    private String cvv;
    private String cardExpiry;
    private String cardNumber;
    private String publicKey;
    private String encryptionKey;
    private String countryCode;
    private String currencyCode;
    private String email;
    private String firstName;
    private String lastName;
    private String narration;
    private String transactionReference;
    private boolean isLive;
    private boolean saveCard;
    private boolean isCard;
    private boolean isAccount;
    private boolean isBankTransfer;


    public BundleData(double amount, String cvv, String cardExpiry, String cardNumber, String publicKey, String encryptionKey, String countryCode,
                      String currencyCode, String email, String firstName, String lastName, String narration, String transactionReference, boolean isLive,
                      boolean saveCard, boolean isCard, boolean isAccount, boolean isBankTransfer) {
        this.amount = amount;
        this.cvv = cvv;
        this.cardExpiry = cardExpiry;
        this.cardNumber = cardNumber;
        this.publicKey = publicKey;
        this.encryptionKey = encryptionKey;
        this.countryCode = countryCode;
        this.currencyCode = currencyCode;
        this.email = email;
        this.firstName = firstName;
        this.lastName = lastName;
        this.narration = narration;
        this.transactionReference = transactionReference;
        this.isLive = isLive;
        this.saveCard = saveCard;
        this.isCard = isCard;
        this.isAccount = isAccount;
        this.isBankTransfer = isBankTransfer;
    }

    protected BundleData(Parcel in) {
        amount = in.readDouble();
        cvv = in.readString();
        cardExpiry = in.readString();
        cardNumber = in.readString();
        publicKey = in.readString();
        encryptionKey = in.readString();
        countryCode = in.readString();
        currencyCode = in.readString();
        email = in.readString();
        firstName = in.readString();
        lastName = in.readString();
        narration = in.readString();
        transactionReference = in.readString();
        isLive = in.readByte() != 0;
        saveCard = in.readByte() != 0;
        isCard = in.readByte() != 0;
        isAccount = in.readByte() != 0;
        isBankTransfer = in.readByte() != 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeDouble(amount);
        dest.writeString(cvv);
        dest.writeString(cardExpiry);
        dest.writeString(cardNumber);
        dest.writeString(publicKey);
        dest.writeString(encryptionKey);
        dest.writeString(countryCode);
        dest.writeString(currencyCode);
        dest.writeString(email);
        dest.writeString(firstName);
        dest.writeString(lastName);
        dest.writeString(narration);
        dest.writeString(transactionReference);
        dest.writeByte((byte) (isLive ? 1 : 0));
        dest.writeByte((byte) (saveCard ? 1 : 0));
        dest.writeByte((byte) (isCard ? 1 : 0));
        dest.writeByte((byte) (isAccount ? 1 : 0));
        dest.writeByte((byte) (isBankTransfer ? 1 : 0));
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<BundleData> CREATOR = new Creator<BundleData>() {
        @Override
        public BundleData createFromParcel(Parcel in) {
            return new BundleData(in);
        }

        @Override
        public BundleData[] newArray(int size) {
            return new BundleData[size];
        }
    };

    public double getAmount() {
        return amount;
    }

    public void setAmount(double amount) {
        this.amount = amount;
    }

    public String getCvv() {
        return cvv;
    }

    public void setCvv(String cvv) {
        this.cvv = cvv;
    }

    public String getCardExpiry() {
        return cardExpiry;
    }

    public void setCardExpiry(String cardExpiry) {
        this.cardExpiry = cardExpiry;
    }

    public String getCardNumber() {
        return cardNumber;
    }

    public void setCardNumber(String cardNumber) {
        this.cardNumber = cardNumber;
    }

    public String getPublicKey() {
        return publicKey;
    }

    public void setPublicKey(String publicKey) {
        this.publicKey = publicKey;
    }

    public String getEncryptionKey() {
        return encryptionKey;
    }

    public void setEncryptionKey(String encryptionKey) {
        this.encryptionKey = encryptionKey;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getCurrencyCode() {
        return currencyCode;
    }

    public void setCurrencyCode(String currencyCode) {
        this.currencyCode = currencyCode;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    public String getNarration() {
        return narration;
    }

    public void setNarration(String narration) {
        this.narration = narration;
    }

    public String getTransactionReference() {
        return transactionReference;
    }

    public void setTransactionReference(String transactionReference) {
        this.transactionReference = transactionReference;
    }

    public boolean isLive() {
        return isLive;
    }

    public void setLive(boolean live) {
        isLive = live;
    }

    public boolean isSaveCard() {
        return saveCard;
    }

    public void setSaveCard(boolean saveCard) {
        this.saveCard = saveCard;
    }

    public boolean isCard() {
        return isCard;
    }

    public void setCard(boolean card) {
        isCard = card;
    }

    public boolean isAccount() {
        return isAccount;
    }

    public void setAccount(boolean account) {
        isAccount = account;
    }

    public boolean isBankTransfer() {
        return isBankTransfer;
    }

    public void setBankTransfer(boolean bankTransfer) {
        isBankTransfer = bankTransfer;
    }
}
